import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

// Define pie chart rendering function
const render = (data) => {
  const pieData = pie()
    .sort(null)
    .value((d) => d.Vancouver)(data);
  const colors = scaleOrdinal(schemeCategory10);
  const segments = arc()
    .innerRadius(0)
    .outerRadius(200)
    .padAngle(0)
    .padRadius(0);

  // Render pie chart sections
  const sections = svg
    .append('g')
    .attr(
      'transform',
      `translate(${width / 2},${height / 2})`,
    )
    .selectAll('path')
    .data(pieData);
  sections
    .enter()
    .append('path')
    .attr('d', segments)
    .attr('fill', (d, i) => colors(i));

  // Render legends
  const legends = svg
    .append('g')
    .attr('transform', 'translate(700,100)')
    .selectAll('.legends')
    .data(pieData);
  const legend = legends
    .enter()
    .append('g')
    .classed('.legends', true)
    .attr('transform', (d, i) => {
      return `translate(0,${(i + 1) * 30})`;
    });

  // Render legend rectangles
  legend
    .append('rect')
    .attr('width', 22)
    .attr('height', 25)
    .attr('fill', (d, i) => colors(i));

  // Render legend text (year)
  legend
    .append('text')
    .attr('x', 28)
    .attr('y', 18)
    .attr('class', 'legend_text')
    .text((d) => d.data.Year);
};

// URL of the CSV data
const csvUrl =
  'https://gist.githubusercontent.com/Yashwanth0402/e97c111c9f158eeb602089ce5500570a/raw/b249671479cf542aca212cc2b39c48ebbe45f0fb/gistfile1.txt';

// Load the data and render the pie chart
csv(csvUrl).then((csvData) => {
  if (csvData) {
    render(csvData);
  }
});
